#ifndef VELOCITY_INFO_H
#define VELOCITY_INFO_H

/*!
  \file
  \brief xԂ

  \author Satofumi KAMIMURA

  $Id$
*/

#include "bodyPosition.h"


/*!
  \brief ϑx̊Ǘ
*/
typedef struct {
  int straight_mm_sec_vel;
  int rotate_div16_sec_vel;
} velocityInfo_t;


//#include "cpp_extern_macro.h"
BEGIN_C_DECLS;

extern void initVelocityInfo(velocityInfo_t *vel);
extern void updateVelocityInfo(velocityInfo_t *vel, bodyPosition_t *bodyPos);

END_C_DECLS;
#endif /* !VELOCITY_INFO_H */
